@@ -30,7 +30,6 @@ from avocado.utils import stacktrace
 from avocado.utils import process
 from avocado.utils import genio
 
-from virttest import asset
 from virttest import error_event
 from virttest import bootstrap
 from virttest import data_dir
@@ -41,6 +40,9 @@ from virttest import utils_params
 from virttest import utils_misc
 from virttest import version
 
+from avocado_vt import utils
+
+
 # avocado-vt no longer needs autotest for the majority of its functionality,
 # except by:
 # 1) Run autotest on VMs
@@ -330,43 +332,18 @@ class VirtTest(test.Test):
                             "as root may produce unexpected results!!!")
             logging.warning("")
 
-        # Find the test
-        subtest_dirs = []
         test_filter = bootstrap.test_filter
-
-        other_subtests_dirs = params.get("other_tests_dirs", "")
-        for d in other_subtests_dirs.split():
-            # If d starts with a "/" an absolute path will be assumed
-            # else the relative path will be searched in the bin_dir
-            subtestdir = os.path.join(self.bindir, d, "tests")
-            if not os.path.isdir(subtestdir):
-                raise exceptions.TestError("Directory %s does not "
-                                           "exist" % subtestdir)
-            subtest_dirs += data_dir.SubdirList(subtestdir,
-                                                test_filter)
-
+        subtest_dirs = utils.find_subtest_dirs(params.get("other_tests_dirs", ""),
+                                               self.bindir,
+                                               test_filter)
         provider = params.get("provider", None)
 
         if provider is None:
-            # Verify if we have the correspondent source file for
-            # it
-            generic_subdirs = asset.get_test_provider_subdirs(
-                'generic')
-            for generic_subdir in generic_subdirs:
-                subtest_dirs += data_dir.SubdirList(generic_subdir,
-                                                    test_filter)
-            specific_subdirs = asset.get_test_provider_subdirs(
-                params.get("vm_type"))
-            for specific_subdir in specific_subdirs:
-                subtest_dirs += data_dir.SubdirList(
-                    specific_subdir, bootstrap.test_filter)
+            subtest_dirs += utils.find_generic_specific_subtest_dirs(
+                params.get("vm_type"), test_filter)
         else:
-            provider_info = asset.get_test_provider_info(provider)
-            for key in provider_info['backends']:
-                subtest_dirs += data_dir.SubdirList(
-                    provider_info['backends'][key]['path'],
-                    bootstrap.test_filter)
-
+            subtest_dirs += utils.find_provider_subtest_dirs(provider,
+                                                             test_filter)
         subtest_dir = None
 
         # Get the test routine corresponding to the specified
@@ -378,28 +355,10 @@ class VirtTest(test.Test):
                       params.get("provider", None))
 
         t_types = params.get("type").split()
-        # Make sure we can load provider_lib in tests
-        for s in subtest_dirs:
-            if os.path.dirname(s) not in sys.path:
-                sys.path.insert(0, os.path.dirname(s))
 
-        test_modules = {}
-        for t_type in t_types:
-            for d in subtest_dirs:
-                module_path = os.path.join(d, "%s.py" % t_type)
-                if os.path.isfile(module_path):
-                    logging.debug("Found subtest module %s",
-                                  module_path)
-                    subtest_dir = d
-                    break
-            if subtest_dir is None:
-                msg = ("Could not find test file %s.py on test"
-                       "dirs %s" % (t_type, subtest_dirs))
-                raise exceptions.TestError(msg)
-            # Load the test module
-            f, p, d = imp.find_module(t_type, [subtest_dir])
-            test_modules[t_type] = imp.load_module(t_type, f, p, d)
-            f.close()
+        utils.insert_dirs_to_path(subtest_dirs)
+
+        test_modules = utils.find_test_modules(t_types, subtest_dirs)
 
         # Open the environment file
         env_filename = os.path.join(data_dir.get_tmp_dir(),
