@@ -6,7 +6,6 @@ http://libvirt.org/formatnode.html
 import os
 
 from virttest.libvirt_xml import base, xcepts, accessors
-from virttest.compat_52lts import results_stdout_52lts, results_stderr_52lts
 
 
 class CAPXML(base.LibvirtXMLBase):
@@ -489,10 +488,10 @@ class NodedevXML(NodedevXMLBase):
         nodedevxml = NodedevXML(virsh_instance=virsh_instance)
         dumpxml_result = virsh_instance.nodedev_dumpxml(dev_name)
         if dumpxml_result.exit_status:
-            stderr = results_stderr_52lts(dumpxml_result)
+            stderr = dumpxml_result.stderr_text
             raise xcepts.LibvirtXMLError("Nodedev_dumpxml %s failed.\n"
                                          "Error: %s." % (dev_name, stderr))
-        nodedevxml.xml = results_stdout_52lts(dumpxml_result)
+        nodedevxml.xml = dumpxml_result.stdout_text
 
         return nodedevxml
 
