@@ -290,13 +290,13 @@ class MigrationTest(object):
 
                     if migration_started:
                         logging.info("Migration started for %s", vm.name)
+                        time.sleep(3)  # To avoid executing the command lines before starting migration
                         if func == process.run:
                             try:
                                 func(args['func_params'], shell=args['shell'])
                             except KeyError:
                                 func(args['func_params'])
                         elif func == virsh.migrate_postcopy:
-                            time.sleep(3)  # To avoid of starting postcopy before starting migration
                             func(vm.name, uri=srcuri, debug=True)
                         else:
                             if 'func_params' in args:
@@ -310,7 +310,7 @@ class MigrationTest(object):
                 logging.debug("start_time:%d, eclipse_time:%d", stime, eclipse_time)
                 if eclipse_time < thread_timeout:
                     migration_thread.join(thread_timeout - eclipse_time)
-                if migration_thread.isAlive():
+                if migration_thread.is_alive():
                     logging.error("Migrate %s timeout.", migration_thread)
                     self.RET_LOCK.acquire()
                     self.RET_MIGRATION = False
@@ -330,7 +330,7 @@ class MigrationTest(object):
                 thread1.join(thread_timeout)
                 thread2.join(thread_timeout)
                 vm_remote = vm
-                if thread1.isAlive() or thread1.isAlive():
+                if thread1.is_alive() or thread1.is_alive():
                     logging.error("Cross migrate timeout.")
                     self.RET_LOCK.acquire()
                     self.RET_MIGRATION = False
@@ -350,7 +350,7 @@ class MigrationTest(object):
             # listen threads until they end
             for thread in migration_threads:
                 thread.join(thread_timeout)
-                if thread.isAlive():
+                if thread.is_alive():
                     logging.error("Migrate %s timeout.", thread)
                     self.RET_LOCK.acquire()
                     self.RET_MIGRATION = False
@@ -476,3 +476,29 @@ class MigrationTest(object):
         else:
             raise exceptions.TestError("Fail to cancel migration: [%s]"
                                        % pid.strip())
+
+    def set_migratepostcopy(self, vm_name, uri=None):
+        """
+        Switch to postcopy during migration.
+
+        :param vm_name: vm's name
+        :param uri: target virsh uri
+        :raise: test.error when command fails
+        """
+        cmd = "event --loop --all"
+        virsh_event_session = virsh.VirshSession(virsh_exec=virsh.VIRSH_EXEC,
+                                                 auto_close=True,
+                                                 uri=uri)
+        virsh_event_session.sendline(cmd)
+
+        if not utils_misc.wait_for(
+           lambda: not virsh.migrate_postcopy(vm_name, uri=uri,
+                                              debug=True).exit_status, 10):
+            raise exceptions.TestError("Failed to set migration postcopy.")
+
+        exp_str = "Suspended Post-copy"
+        if not utils_misc.wait_for(
+           lambda: re.findall(exp_str,
+                              virsh_event_session.get_stripped_output()), 30):
+            raise exceptions.TestError("Unalbe to find event {}"
+                                       .format(exp_str))
